@@ -29,7 +29,7 @@ from pitivi.log.loggable import Loggable
 from pitivi.encode import encoders_muxer_compatible, muxer_can_sink_raw_audio, muxer_can_sink_raw_video
 from glade import GladeWidget
 from gstwidget import GstElementSettingsDialog
-
+import gobject
 from gettext import gettext as _
 
 class ExportSettingsWidget(GladeWidget, Loggable):
@@ -63,7 +63,7 @@ class ExportSettingsWidget(GladeWidget, Loggable):
                      ("32 bit", 32) )
 
 
-    def __init__(self):
+    def __init__(self, app):
         GladeWidget.__init__(self)
         Loggable.__init__(self)
         self.settings = None
@@ -76,6 +76,7 @@ class ExportSettingsWidget(GladeWidget, Loggable):
         self.muxer = None
         self.vencoder = None
         self.aencoder = None
+        self.app = app
         self._loading = False
 
     def setSettings(self, settings):
@@ -107,7 +108,8 @@ class ExportSettingsWidget(GladeWidget, Loggable):
             fps = preset[3:5]
             videolist.append(["%s - %s" % (preset[0], fps_map[fps])])
 
-        videolist.append(["Custom"])
+        # i18n: string for custom video width/height/framerate settings
+        videolist.append([_("Custom")])
 
         # find out from the project settings which combo to take
         idx = 0
@@ -140,7 +142,8 @@ class ExportSettingsWidget(GladeWidget, Loggable):
         audiolist.clear()
         for preset in self.audio_presets:
             audiolist.append([preset[0]])
-        audiolist.append(["Custom"])
+        # i18n: string for custom audio rate/depth/channels settings
+        audiolist.append([_("Custom")])
 
         idx = 0
         for preset in self.audio_presets:
@@ -291,7 +294,7 @@ class ExportSettingsWidget(GladeWidget, Loggable):
                 selected = idx
             idx = idx + 1
         if muxer_can_sink_raw_video(muxer):
-            venclist.append(["Raw Video"])
+            venclist.append([_("Raw Video")])
             if prevvenc == None:
                 selected = idx
         self.vcodeccbox.set_active(selected)
@@ -306,13 +309,28 @@ class ExportSettingsWidget(GladeWidget, Loggable):
                 selected = idx
             idx = idx + 1
         if muxer_can_sink_raw_audio(muxer):
-            aenclist.append(["Raw Audio"])
+            aenclist.append([_("Raw Audio")])
             if prevaenc == None:
                 selected = idx
         self.acodeccbox.set_active(selected)
 
     def runSettingsDialog(self, factory, settings={}):
+        def configureEventCb(window, event):
+            self.app.settings.elementSettingsDialogWidth = event.width
+            self.app.settings.elementSettingsDialogHeight = event.height
+
+        def mapEventCb(window, event):
+            def reallySetWindowSize():
+                dialog.window.resize(self.app.settings.elementSettingsDialogWidth,
+                    self.app.settings.elementSettingsDialogHeight)
+                dialog.window.disconnect(mapEventId)
+                window.connect("configure-event", configureEventCb)
+                return False
+            gobject.idle_add(reallySetWindowSize)
+
         dialog = GstElementSettingsDialog(factory, settings)
+        mapEventId = dialog.window.connect("map-event", mapEventCb)
+
         if dialog.run() == gtk.RESPONSE_OK:
             dialog.hide()
             settings = dialog.getSettings()
@@ -412,13 +430,13 @@ class ExportSettingsWidget(GladeWidget, Loggable):
 
 class ExportSettingsDialog(gtk.Dialog):
 
-    def __init__(self, settings):
+    def __init__(self, app, settings):
         gtk.Dialog.__init__(self, parent=None,
                             title=_("Export settings"),
                             flags=gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
                             buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
                                      gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
-        self.setwidget = ExportSettingsWidget()
+        self.setwidget = ExportSettingsWidget(app)
         self.vbox.pack_start(self.setwidget)
         self.setwidget.setSettings(settings)
         self.setwidget.show_all()
